@@ -19,12 +19,14 @@
 #include <linux/unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <ctype.h>
 #include <errno.h>
 #include <sys/syscall.h>
 #include <unistd.h>
 #include <linux/capability.h>
 #include <string.h>
 #include <linux/vzcalluser.h>
+#include <sys/prctl.h>
 
 #include "cap.h"
 #include "res.h"
@@ -32,6 +34,16 @@
 #include "logger.h"
 #include "util.h"
 
+#ifndef _LINUX_CAPABILITY_VERSION_1
+# define _LINUX_CAPABILITY_VERSION_1  0x19980330
+#endif
+#ifndef _LINUX_CAPABILITY_VERSION_2
+# define _LINUX_CAPABILITY_VERSION_2  0x20071026
+#endif
+#ifndef _LINUX_CAPABILITY_VERSION_3
+# define _LINUX_CAPABILITY_VERSION_3  0x20080522
+#endif
+
 #ifndef	CAP_AUDIT_WRITE
 #define	CAP_AUDIT_WRITE	29
 #endif
@@ -42,6 +54,11 @@
 #define	CAP_SETFCAP	31
 #endif
 
+/* From /usr/include/linux/prctl.h */
+#ifndef PR_CAPBSET_DROP
+# define PR_CAPBSET_DROP 24
+#endif
+
 #define CAPDEFAULTMASK_OLD				  \
 	CAP_TO_MASK(CAP_CHOWN)				| \
 	CAP_TO_MASK(CAP_DAC_OVERRIDE)			| \
@@ -73,6 +90,11 @@
 	CAP_TO_MASK(CAP_SETPCAP)			| \
 	CAP_TO_MASK(CAP_SETFCAP)
 
+#define CAPDEFAULTMASK_UPSTREAM				  \
+	CAPDEFAULTMASK					| \
+	CAP_TO_MASK(CAP_SYS_ADMIN)			| \
+	CAP_TO_MASK(CAP_NET_ADMIN)
+
 static char *cap_names[] = {
 "CHOWN",		/*	0	*/
 "DAC_OVERRIDE",		/*	1	*/
@@ -149,6 +171,7 @@ void build_cap_str(cap_param *new, cap_param *old, const char *delim,
 		char *buf, int len)
 {
 	unsigned int i;
+	unsigned int j = 0;
 	int r;
 	char *sp, *ep;
 
@@ -170,7 +193,7 @@ void build_cap_str(cap_param *new, cap_param *old, const char *delim,
 		else
 			continue;
 		r = snprintf(sp, ep - sp, "%s%s:%s",
-				i == 0 ? "" : delim,
+				j++ == 0 ? "" : delim,
 				cap_names[i],
 				op == 1 ? "on" : "off");
 		if (r < 0 || sp + r >= ep)
@@ -179,22 +202,95 @@ void build_cap_str(cap_param *new, cap_param *old, const char *delim,
 	}
 }
 
+void print_json_cap(cap_param *cap)
+{
+	unsigned int i, j = 0;
+	unsigned int l = 0;
+	char lc[64] = "";
+
+	for (i = 0; i < ARRAY_SIZE(cap_names); i++) {
+		int op = 0;
+
+		if (CAP_TO_MASK(i) & cap->on)
+			op = 1;
+		else if (CAP_TO_MASK(i) & cap->off)
+			op = 2;
+		else
+			continue;
+
+		for (l = 0; cap_names[i][l]; l++)
+			lc[l] = tolower(cap_names[i][l]);
+
+		printf("%s      \"%s\": %s",
+				j++ == 0 ? "{\n" : ",\n",
+				lc,
+				op == 1 ? "true" : "false");
+	}
+
+	if (j)
+		printf("\n    }");
+	else
+		printf("null");
+}
+
+static int set_cap_bound(cap_t mask)
+{
+	int i;
+
+	for (i = 0; ; i++) {
+		/* Currently (kernel 3.5) in-kernel cap size is u64,
+		 * but it might change in the future */
+		if (i == sizeof(__u64) * 8) {
+			errno = EOVERFLOW;
+			return -1;
+		}
+
+		if ((1ULL << i) & mask)
+			continue;
+
+		if (prctl(PR_CAPBSET_DROP, i) == -1) {
+			if (i == 0)
+				return 1; /* PR_CAPBSET_DROP not supported */
+
+			/* vzctl could have been built with the headers
+			 * different from those of the running kernel, so
+			 * it can't rely on CAP_LAST_CAP value. Therefore,
+			 * try dropping all caps until EINVAL.
+			 */
+			if (errno == EINVAL) /* All capabilities were set */
+				break;
+			return -1;
+		}
+	}
+
+	return 0;
+}
+
 static int set_cap(envid_t veid, cap_t mask, int pid)
 {
 	struct __user_cap_header_struct header;
-	struct __user_cap_data_struct data;
+	struct __user_cap_data_struct data[2]; /* as of .._VERSION_3 */
 
 	memset(&header, 0, sizeof(header));
-	header.version = _LINUX_CAPABILITY_VERSION;
 	capget(&header, NULL); /* Get linux capability version from kernel */
+	switch (header.version) {
+		case _LINUX_CAPABILITY_VERSION_1:
+		case _LINUX_CAPABILITY_VERSION_2:
+		case _LINUX_CAPABILITY_VERSION_3:
+			break;
+		default:
+			errno = ENOSYS;
+			/* Error is printed by vps_set_cap() */
+			return -1;
+	}
 	header.pid = pid;
 
 	memset(&data, 0, sizeof(data));
-	data.effective = mask;
-	data.permitted = mask;
-	data.inheritable = mask;
+	data[0].effective = mask;
+	data[0].permitted = mask;
+	data[0].inheritable = mask;
 
-	return capset(&header, &data);
+	return capset(&header, data);
 }
 
 static inline cap_t make_cap_mask(cap_t def, cap_t on, cap_t off)
@@ -202,14 +298,23 @@ static inline cap_t make_cap_mask(cap_t def, cap_t on, cap_t off)
 	return (def | on) & ~off;
 }
 
-int vps_set_cap(envid_t veid, struct env_param *env, cap_param *cap)
+int vps_set_cap(envid_t veid, struct env_param *env, cap_param *cap,
+		int is_upstream)
 {
-	cap_t mask;
+	cap_t mask = CAPDEFAULTMASK;
+	int ret;
 
 	if ((env->features_known & env->features_mask) & VE_FEATURE_BRIDGE)
 		cap_raise(cap->on, CAP_NET_ADMIN);
 
-	mask = make_cap_mask(CAPDEFAULTMASK, cap->on, cap->off);
+	if (is_upstream)
+		mask = CAPDEFAULTMASK_UPSTREAM;
+	mask = make_cap_mask(mask, cap->on, cap->off);
+
+	ret = set_cap_bound(mask);
+	if (ret < 0)
+		goto out;
+
 	if (set_cap(veid, mask, 0) == 0)
 		return 0;
 
@@ -217,7 +322,7 @@ int vps_set_cap(envid_t veid, struct env_param *env, cap_param *cap)
 	mask = make_cap_mask(CAPDEFAULTMASK_OLD, cap->on, cap->off);
 	if (set_cap(veid, mask, 0) == 0)
 		return 0;
-
+out:
 	logger(-1, errno, "Unable to set capability");
 	return VZ_SET_CAP;
 }
