@@ -417,7 +417,7 @@ static int conf_store_int(list_head_t *conf, const char *name, int val)
 
 static int conf_store_float(list_head_t *conf, const char *name, float val)
 {
-	char buf[] = "1.34567e+12";
+	char buf[16];
 
 	snprintf(buf, sizeof(buf), "%g", val);
 	return conf_store_str(conf, name, buf);
@@ -2715,7 +2715,7 @@ static int write_conf(const char *fname, list_head_t *head)
 	const char *suffix = ".tmp";
 	char *fmt;
 
-	file = canonicalize_file_name(fname);
+	file = realpath(fname, NULL);
 	if (file == NULL) {
 		if (errno != ENOENT) {
 			logger(-1, errno, "Unable to resolve path %s", fname);
