@@ -430,7 +430,6 @@ int vps_run_script(vps_handler *h, envid_t veid, char *script, vps_param *vps_p)
 	int ret, retry;
 	char *argv[2];
 	const char *root = vps_p->res.fs.root;
-	const char *private = vps_p->res.fs.private;
 
 	if (stat_file(script) != 1) {
 		logger(-1, 0, "Script not found: %s", script);
@@ -452,7 +451,7 @@ int vps_run_script(vps_handler *h, envid_t veid, char *script, vps_param *vps_p)
 	if (!(is_run = vps_is_run(h, veid))) {
 		if ((ret = check_ub(h, &vps_p->res.ub)))
 			return ret;
-		is_mounted = vps_is_mounted(root, private);
+		is_mounted = vps_is_mounted(&vps_p->res.fs);
 		if (is_mounted == 0) {
 			if ((ret = fsmount(veid, &vps_p->res.fs,
 				&vps_p->res.dq, 0)))
