@@ -47,6 +47,7 @@
 #include "image.h"
 #include "vzfeatures.h"
 #include "io.h"
+#include "iptables.h"
 
 static struct Cveinfo *veinfo = NULL;
 static int n_veinfo = 0;
@@ -398,6 +399,30 @@ static void print_layout(struct Cveinfo *p, int index)
 				"%-6s",	layout2str(p->layout));
 }
 
+static void print_netfilter(struct Cveinfo *p, int index)
+{
+	if (fmt_json)
+		print_json_str(netfilter_mask2str(p->nf_mask));
+	else
+		p_buf += snprintf(p_buf, e_buf - p_buf,
+				"%-9s",	netfilter_mask2str(p->nf_mask));
+}
+
+static void print_capability(struct Cveinfo *p, int index)
+{
+	char buf[STR_SIZE] = "-";
+	unsigned int l;
+
+	if (fmt_json)
+		return print_json_cap(&p->cap);
+
+	build_cap_str(&p->cap, NULL, ",", buf, sizeof(buf));
+	for (l = 0; buf[l]; l++)
+		buf[l] = tolower(buf[l]);
+	p_buf += snprintf(p_buf, e_buf - p_buf,
+			"%-15s", buf);
+}
+
 static void print_features(struct Cveinfo *p, int index)
 {
 	int r;
@@ -767,6 +792,8 @@ UBC_FIELD(swappages, SWAPP),
 {"disabled", "DISABL", "%6s", 0, RES_NONE, print_disabled, none_sort_fn},
 {"vm_overcommit", "VM_OVC", "%6s", 0, RES_NONE,
 	print_vm_overcommit, none_sort_fn},
+{"netfilter", "NETFILTER", "%-9s", 0, RES_NONE, print_netfilter, none_sort_fn},
+{"capability", "CAPABILITY", "%-15s", 0, RES_NONE, print_capability, none_sort_fn},
 };
 
 static void *x_malloc(int size)
@@ -1151,6 +1178,8 @@ FOR_ALL_UBC(MERGE_UBC)
 	if (opt->origin_sample != NULL)
 		ve->origin_sample = strdup(opt->origin_sample);
 	ve->layout = res->fs.layout;
+	ve->nf_mask = res->env.nf_mask;
+	ve->cap = res->cap;
 }
 
 static int read_ves_param()
@@ -1577,8 +1606,15 @@ static int get_mounted_status(int detailed)
 {
 	int i;
 	char buf[512];
+	fs_param fs = {};
 
 	for (i = 0; i < n_veinfo; i++) {
+		if (veinfo[i].layout == 0) {
+			int ploop = guess_ve_private_is_ploop(veinfo[i].private);
+			veinfo[i].layout = ploop ? VE_LAYOUT_PLOOP : VE_LAYOUT_SIMFS;
+		}
+		fs.layout = veinfo[i].layout;
+
 		if (veinfo[i].status == VE_RUNNING)
 			continue;
 		if (veinfo[i].private == NULL ||
@@ -1594,26 +1630,14 @@ static int get_mounted_status(int detailed)
 			veinfo[i].status = VE_SUSPENDED;
 		if (veinfo[i].root == NULL)
 			continue;
-		if (vps_is_mounted(veinfo[i].root, veinfo[i].private) == 1)
+		fs.root = veinfo[i].root;
+		fs.private = veinfo[i].private;
+		if (vps_is_mounted(&fs) == 1)
 			veinfo[i].status = VE_MOUNTED;
 	}
 	return 0;
 }
 
-static int get_ves_layout()
-{
-	int i;
-
-	for (i = 0; i < n_veinfo; i++) {
-		if (veinfo[i].layout == 0) {
-			int ploop = guess_ve_private_is_ploop(veinfo[i].private);
-			veinfo[i].layout = ploop ? VE_LAYOUT_PLOOP : VE_LAYOUT_SIMFS;
-		}
-	}
-
-	return 0;
-}
-
 static int get_ve_cpunum(struct Cveinfo *ve) {
 	char path[] = "/proc/vz/fairsched/2147483647/cpu.nr_cpus";
 	int veid = ve->veid;
@@ -1844,7 +1868,6 @@ static int collect()
 	if (check_param(RES_IO))
 		update_ves_io();
 	get_mounted_status(check_param(RES_STATUS));
-	get_ves_layout();
 	if (check_param(RES_QUOTA)) {
 		get_run_quota_stat();
 		get_ves_ploop_info();
